@@ -2,6 +2,8 @@
 Amazon OAuth2 backend, docs at:
     http://psa.matiasaguirre.net/docs/backends/amazon.html
 """
+import ssl
+
 from social.backends.oauth import BaseOAuth2
 
 
@@ -13,6 +15,7 @@ class AmazonOAuth2(BaseOAuth2):
     DEFAULT_SCOPE = ['profile']
     REDIRECT_STATE = False
     ACCESS_TOKEN_METHOD = 'POST'
+    SSL_PROTOCOL = ssl.PROTOCOL_TLSv1
     EXTRA_DATA = [
         ('refresh_token', 'refresh_token', True),
         ('user_id', 'user_id'),
