@@ -2,11 +2,10 @@
 Google OpenId, OAuth2, OAuth1, Google+ Sign-in backends, docs at:
     http://psa.matiasaguirre.net/docs/backends/google.html
 """
-from requests import HTTPError
-
+from social.utils import handle_http_errors
 from social.backends.open_id import OpenIdAuth, OpenIdConnectAuth
 from social.backends.oauth import BaseOAuth2, BaseOAuth1
-from social.exceptions import AuthMissingParameter, AuthCanceled
+from social.exceptions import AuthMissingParameter
 
 
 class BaseGoogleAuth(object):
@@ -60,7 +59,7 @@ class BaseGoogleOAuth2API(BaseGoogleAuth):
                 default_scope = self.DEPRECATED_DEFAULT_SCOPE
             else:
                 default_scope = self.DEFAULT_SCOPE
-            scope += default_scope or []
+            scope = scope + (default_scope or [])
         return scope
 
     def user_data(self, access_token, *args, **kwargs):
@@ -74,6 +73,12 @@ class BaseGoogleOAuth2API(BaseGoogleAuth):
             'alt': 'json'
         })
 
+    def revoke_token_params(self, token, uid):
+        return {'token': token}
+
+    def revoke_token_headers(self, token, uid):
+        return {'Content-type': 'application/json'}
+
 
 class GoogleOAuth2(BaseGoogleOAuth2API, BaseOAuth2):
     """Google OAuth2 authentication backend"""
@@ -84,7 +89,8 @@ class GoogleOAuth2(BaseGoogleOAuth2API, BaseOAuth2):
     ACCESS_TOKEN_METHOD = 'POST'
     REVOKE_TOKEN_URL = 'https://accounts.google.com/o/oauth2/revoke'
     REVOKE_TOKEN_METHOD = 'GET'
-    DEFAULT_SCOPE = ['email', 'profile']
+    # The order of the default scope is important
+    DEFAULT_SCOPE = ['openid', 'email', 'profile']
     DEPRECATED_DEFAULT_SCOPE = [
         'https://www.googleapis.com/auth/userinfo.email',
         'https://www.googleapis.com/auth/userinfo.profile'
@@ -95,12 +101,6 @@ class GoogleOAuth2(BaseGoogleOAuth2API, BaseOAuth2):
         ('token_type', 'token_type', True)
     ]
 
-    def revoke_token_params(self, token, uid):
-        return {'token': token}
-
-    def revoke_token_headers(self, token, uid):
-        return {'Content-type': 'application/json'}
-
 
 class GooglePlusAuth(BaseGoogleOAuth2API, BaseOAuth2):
     name = 'google-plus'
@@ -113,6 +113,7 @@ class GooglePlusAuth(BaseGoogleOAuth2API, BaseOAuth2):
     REVOKE_TOKEN_METHOD = 'GET'
     DEFAULT_SCOPE = [
         'https://www.googleapis.com/auth/plus.login',
+        'https://www.googleapis.com/auth/plus.me',
     ]
     DEPRECATED_DEFAULT_SCOPE = [
         'https://www.googleapis.com/auth/plus.login',
@@ -134,33 +135,29 @@ class GooglePlusAuth(BaseGoogleOAuth2API, BaseOAuth2):
             params['redirect_uri'] = 'postmessage'
         return params
 
+    @handle_http_errors
     def auth_complete(self, *args, **kwargs):
-        if 'access_token' in self.data and not 'code' in self.data:
-            raise AuthMissingParameter(self, 'access_token or code')
-
-        # Token won't be available in plain server-side workflow
-        token = self.data.get('access_token')
-        if token:
-            self.process_error(self.get_json(
+        if 'access_token' in self.data:  # Client-side workflow
+            token = self.data.get('access_token')
+            response = self.get_json(
                 'https://www.googleapis.com/oauth2/v1/tokeninfo',
                 params={'access_token': token}
-            ))
-
-        try:
+            )
+            self.process_error(response)
+            return self.do_auth(token, response=response, *args, **kwargs)
+        elif 'code' in self.data:  # Server-side workflow
             response = self.request_access_token(
                 self.ACCESS_TOKEN_URL,
                 data=self.auth_complete_params(),
                 headers=self.auth_headers(),
                 method=self.ACCESS_TOKEN_METHOD
             )
-        except HTTPError as err:
-            if err.response.status_code == 400:
-                raise AuthCanceled(self)
-            else:
-                raise
-        self.process_error(response)
-        return self.do_auth(response['access_token'], response=response,
-                            *args, **kwargs)
+            self.process_error(response)
+            return self.do_auth(response['access_token'],
+                                response=response,
+                                *args, **kwargs)
+        else:
+            raise AuthMissingParameter(self, 'access_token or code')
 
 
 class GoogleOAuth(BaseGoogleAuth, BaseOAuth1):
