@@ -1,7 +1,7 @@
 import datetime
 from calendar import timegm
 
-from jwt import DecodeError, ExpiredSignature, decode as jwt_decode
+from jwt import InvalidTokenError, decode as jwt_decode
 
 from openid.consumer.consumer import Consumer, SUCCESS, CANCEL, FAILURE
 from openid.consumer.discover import DiscoveryFailure
@@ -96,6 +96,7 @@ class OpenIdAuth(BaseAuth):
         fullname = values.get('fullname') or ''
         first_name = values.get('first_name') or ''
         last_name = values.get('last_name') or ''
+        email = values.get('email') or ''
 
         if not fullname and first_name and last_name:
             fullname = first_name + ' ' + last_name
@@ -109,10 +110,11 @@ class OpenIdAuth(BaseAuth):
         values.update({'fullname': fullname, 'first_name': first_name,
                        'last_name': last_name,
                        'username': values.get(username_key) or
-                                   (first_name.title() + last_name.title())})
+                                   (first_name.title() + last_name.title()),
+                       'email': email})
         return values
 
-    def extra_data(self, user, uid, response, details):
+    def extra_data(self, user, uid, response, details=None, *args, **kwargs):
         """Return defined extra data names to store in extra_data field.
         Settings will be inspected to get more values names that should be
         stored on extra_data field. Setting name is created from current
@@ -127,7 +129,7 @@ class OpenIdAuth(BaseAuth):
         ax_names = self.setting('AX_EXTRA_DATA')
         values = self.values_from_response(response, sreg_names, ax_names)
         from_details = super(OpenIdAuth, self).extra_data(
-            user, uid, {}, details
+            user, uid, {}, details, *args, **kwargs
         )
         values.update(from_details)
         return values
@@ -327,24 +329,17 @@ class OpenIdConnectAuth(BaseOAuth2):
         try:
             # Decode the JWT and raise an error if the secret is invalid or
             # the response has expired.
-            id_token = jwt_decode(id_token, decryption_key)
-        except (DecodeError, ExpiredSignature) as de:
-            raise AuthTokenError(self, de)
-
-        # Verify the issuer of the id_token is correct
-        if id_token['iss'] != self.ID_TOKEN_ISSUER:
-            raise AuthTokenError(self, 'Incorrect id_token: iss')
+            id_token = jwt_decode(id_token, decryption_key, audience=client_id,
+                                  issuer=self.ID_TOKEN_ISSUER,
+                                  algorithms=['HS256'])
+        except InvalidTokenError as err:
+            raise AuthTokenError(self, err)
 
         # Verify the token was issued in the last 10 minutes
         utc_timestamp = timegm(datetime.datetime.utcnow().utctimetuple())
         if id_token['iat'] < (utc_timestamp - 600):
             raise AuthTokenError(self, 'Incorrect id_token: iat')
 
-        # Verify this client is the correct recipient of the id_token
-        aud = id_token.get('aud')
-        if aud != client_id:
-            raise AuthTokenError(self, 'Incorrect id_token: aud')
-
         # Validate the nonce to ensure the request was not modified
         nonce = id_token.get('nonce')
         if not nonce:
