@@ -85,6 +85,9 @@ class VKOAuth2(BaseOAuth2):
         ('expires_in', 'expires')
     ]
 
+    def get_user_id(self, details, response):
+        return response['uid']
+
     def get_user_details(self, response):
         """Return user details from VK.com account"""
         fullname, first_name, last_name = self.get_user_names(
@@ -97,7 +100,7 @@ class VKOAuth2(BaseOAuth2):
                 'first_name': first_name,
                 'last_name': last_name}
 
-    def user_data(self, access_token, response, *args, **kwargs):
+    def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
         request_data = ['first_name', 'last_name', 'screen_name', 'nickname',
                         'photo'] + self.setting('EXTRA_DATA', [])
@@ -106,10 +109,9 @@ class VKOAuth2(BaseOAuth2):
         data = vk_api(self, 'users.get', {
             'access_token': access_token,
             'fields': fields,
-            'uids': response.get('user_id')
         })
 
-        if data.get('error'):
+        if data and data.get('error'):
             error = data['error']
             msg = error.get('error_msg', 'Unknown error')
             if error.get('error_code') == 5:
@@ -120,7 +122,7 @@ class VKOAuth2(BaseOAuth2):
         if data:
             data = data.get('response')[0]
             data['user_photo'] = data.get('photo')  # Backward compatibility
-        return data
+        return data or {}
 
 
 class VKAppOAuth2(VKOAuth2):
@@ -188,9 +190,9 @@ def vk_api(backend, method, data):
     """
     # We need to perform server-side call if no access_token
     data['v'] = backend.setting('API_VERSION', '3.0')
-    if not 'access_token' in data:
+    if 'access_token' not in data:
         key, secret = backend.get_key_and_secret()
-        if not 'api_id' in data:
+        if 'api_id' not in data:
             data['api_id'] = key
 
         data['method'] = method
