@@ -45,7 +45,9 @@ def get_username(strategy, details, user=None, *args, **kwargs):
         # Generate a unique username for current user using username
         # as base but adding a unique hash at the end. Original
         # username is cut to avoid any field max_length.
-        while storage.user.user_exists(username=final_username):
+        # The final_username may be empty and will skip the loop.
+        while not final_username or \
+              storage.user.user_exists(username=final_username):
             username = short_username + uuid4().hex[:uuid_length]
             final_username = slug_func(clean_func(username[:max_length]))
     else:
@@ -58,8 +60,8 @@ def create_user(strategy, details, user=None, *args, **kwargs):
         return {'is_new': False}
 
     fields = dict((name, kwargs.get(name) or details.get(name))
-                        for name in strategy.setting('USER_FIELDS',
-                                                      USER_FIELDS))
+                  for name in strategy.setting('USER_FIELDS',
+                                               USER_FIELDS))
     if not fields:
         return
 
@@ -73,19 +75,20 @@ def user_details(strategy, details, user=None, *args, **kwargs):
     """Update user details using data from provider."""
     if user:
         changed = False  # flag to track changes
-        protected = strategy.setting('PROTECTED_USER_FIELDS', [])
-        keep = ('username', 'id', 'pk') + tuple(protected)
+        protected = ('username', 'id', 'pk', 'email') + \
+            tuple(strategy.setting('PROTECTED_USER_FIELDS', []))
 
+        # Update user model attributes with the new data sent by the current
+        # provider. Update on some attributes is disabled by default, for
+        # example username and id fields. It's also possible to disable update
+        # on fields defined in SOCIAL_AUTH_PROTECTED_FIELDS.
         for name, value in details.items():
-            # do not update username, it was already generated
-            # do not update configured fields if user already existed
-            if name not in keep and hasattr(user, name):
-                if value and value != getattr(user, name, None):
-                    try:
-                        setattr(user, name, value)
-                        changed = True
-                    except AttributeError:
-                        pass
+            if value and hasattr(user, name):
+                # Check https://github.com/omab/python-social-auth/issues/671
+                current_value = getattr(user, name, None)
+                if not current_value or name not in protected:
+                    changed |= current_value != value
+                    setattr(user, name, value)
 
         if changed:
             strategy.storage.user.changed(user)
