@@ -2,8 +2,6 @@ import time
 import random
 import hashlib
 
-import six
-
 from social.utils import setting_name, module_member
 from social.store import OpenIdStore, OpenIdSessionWrapper
 from social.pipeline import DEFAULT_AUTH_PIPELINE, DEFAULT_DISCONNECT_PIPELINE
@@ -34,10 +32,6 @@ class BaseStrategy(object):
     ALLOWED_CHARS = 'abcdefghijklmnopqrstuvwxyz' \
                     'ABCDEFGHIJKLMNOPQRSTUVWXYZ' \
                     '0123456789'
-    # well-known serializable types
-    SERIALIZABLE_TYPES = (dict, list, tuple, set, bool, type(None)) + \
-                         six.integer_types + six.string_types + \
-                         (six.text_type, six.binary_type,)
     DEFAULT_TEMPLATE_STRATEGY = BaseTemplateStrategy
 
     def __init__(self, storage=None, tpl=None):
@@ -194,3 +188,23 @@ class BaseStrategy(object):
     def build_absolute_uri(self, path=None):
         """Build absolute URI with given (optional) path"""
         raise NotImplementedError('Implement in subclass')
+
+    def request_is_secure(self):
+        """Is the request using HTTPS?"""
+        raise NotImplementedError('Implement in subclass')
+
+    def request_path(self):
+        """path of the current request"""
+        raise NotImplementedError('Implement in subclass')
+
+    def request_port(self):
+        """Port in use for this request"""
+        raise NotImplementedError('Implement in subclass')
+
+    def request_get(self):
+        """Request GET data"""
+        raise NotImplementedError('Implement in subclass')
+
+    def request_post(self):
+        """Request POST data"""
+        raise NotImplementedError('Implement in subclass')
